# ploomber-core

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


```sh
pip install ploomber-core

# or
conda install ploomber-core -c conda-forge
```
